@@ -526,7 +526,70 @@ def GatherTrainingData(dictGeneral:dict,kmer:int,fragmentSize:int,outputPath:str
 
         return None
 
+def GenerateTrainingFile(path:str,organism:str,kmer:int,fragmentSize:int,outputPath:str,pValueAccepted:float) -> None:
+        """Gather Training Data for neural networks to infer origin from horizontal transfers later on. writes file with phylum_organism.csv with rows of matrix as probability vectors of each possible Kmer"""
 
+        print("Gathering Training Data from: ",organism)
+        folderPath=outputPath+'/'+str(kmer)+'_'+str(fragmentSize)+'_'+str(pValueAccepted)
+        filePath=folderPath+'/'+organism.replace("/","-")+'.csv'
+
+        if not os.path.exists(folderPath):
+                os.makedirs(folderPath)
+                
+        if os.path.exists(filePath):
+                print("File is already downloaded, skipping...")
+
+        else:
+                globalSignature=KmerSignature(path,kmer,False)
+                sequence=Read_Sequence(path)
+                #List of accepted signatures
+                trainingSignature=[]
+                listepos= [0]
+                pos=0
+                nbOfSamples=0
+
+                while pos<len(sequence) and nbOfSamples<=50:
+
+
+                        #Cuts sequence fragment
+                        sequenceFragment=sequence[pos:pos+fragmentSize]
+                        seqCut = [sequenceFragment[i:i+kmer] for i in range(len(sequenceFragment)-(kmer-1)) ]
+
+                        #Retrieve signature of fragment
+                        fragmentSignature = Count_Cuts(seqCut,False) +1
+
+                        #Create contingencybof  table
+                        contingency=np.concatenate((globalSignature.values,fragmentSignature.values),axis=0)
+
+                        resultat,pval, dof, expctd = chi2_contingency(contingency)
+                        
+                        #If the fragments belongs to the specie
+                        if pval>pValueAccepted:
+                                #We compute the normalized signature
+                                normalizedSignature=fragmentSignature/np.sum(fragmentSignature.values)
+                                #We convert the signature to a list and put in inside trainingSignature
+                                trainingSignature.append(normalizedSignature.values[0])
+                                nbOfSamples+=1
+
+
+                        if pos+fragmentSize>len(sequence):
+                                fragmentSize=len(sequence)-pos
+                                pos+=fragmentSize
+                        else:
+                                pos+=fragmentSize
+
+                        #Add new position
+                        listepos.append(pos)
+
+                #We convert the signatures in an array and write it in a file
+                trainingSignature=np.array(trainingSignature)
+
+
+                print("Number of Samples Gathered:", len(trainingSignature))
+                print("Size of file:", sys.getsizeof(trainingSignature))
+                np.savetxt(filePath,trainingSignature,delimiter=',')
+
+        return None
 
 
 if __name__=="__main__":
@@ -557,7 +620,10 @@ if __name__=="__main__":
         #print(SequenceHomogeneity('./testGenome.fna',3,1000))
         
         #Test Gathering Data
-        GatherTrainingData(dictio,5,10000,'./',0.05,'bacteria')
+        #GatherTrainingData(dictio,5,10000,'./',0.05,'bacteria')
+        
+        #Test Gathering Single data filePath
+        GenerateTrainingFile('./testGenome.fna','testOrganism',6,10000,'./',0.05)
         
         
 
